@@ -79,7 +79,7 @@ class ImageBuilder(object):  # pylint: disable=too-many-instance-attributes
         """Return the Debian release components to use for the build."""
         components = ['main']
         if not self.free:
-            components += ['contrib', 'non-free']
+            components += ['contrib', 'non-free-firmware', 'non-free']
 
         if self.arguments.release_component:
             for component in self.arguments.release_component:
@@ -107,22 +107,11 @@ class ImageBuilder(object):  # pylint: disable=too-many-instance-attributes
 
     def _get_image_base_name(self):
         """Return the base file name of the final image."""
-        if self.free:
-            # base image is free, but check added components:
-            if 'non-free' in self.release_components:
-                free_tag = 'nonfree'
-            elif 'contrib' in self.release_components:
-                free_tag = 'contrib'
-            else:
-                free_tag = 'free'
-        else:
-            free_tag = 'nonfree'
-
         build_stamp = self.arguments.build_stamp
         build_stamp = build_stamp + '_' if build_stamp else ''
-        return 'freedombox-{distribution}-{free_tag}_{build_stamp}{machine}' \
+        return 'freedombox-{distribution}_{build_stamp}{machine}' \
             '-{architecture}'.format(
-                distribution=self.arguments.distribution, free_tag=free_tag,
+                distribution=self.arguments.distribution,
                 build_stamp=build_stamp, machine=self.machine,
                 architecture=self.architecture)
 
