@@ -361,6 +361,10 @@ class InternalBuilderBackend():
         if hasattr(self.builder, 'install_boot_loader'):
             self.builder.install_boot_loader(self.state)
 
+        if hasattr(self.builder, 'update_initramfs') and \
+           not self.builder.update_initramfs:
+            return
+
         library.update_initramfs(self.state)
 
     def _setup_build_apt(self):
