@@ -1,19 +1,4 @@
-#
-# This file is part of Freedom Maker.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: GPL-3.0-or-later
 """
 Library of small actions that make up image building.
 
@@ -32,6 +17,8 @@ import cliapp
 
 logger = logging.getLogger(__name__)
 
+STABLE_CODENAME = 'bullseye'
+
 
 def run(*args, **kwargs):
     """Run a command."""
@@ -65,7 +52,7 @@ def run_in_chroot(state, *args, **kwargs):
 def path_in_mount(state, path):
     """Return the path inside the mount point of image.
 
-    If as absolute path is provided as path, it will returned as it is.
+    If an absolute path is provided as path, it will returned as it is.
 
     """
     return os.path.join(state['mount_point'], path)
@@ -128,7 +115,7 @@ def create_temp_image(state, image_file):
 
 
 def move_image(state, source_image, target_image):
-    """Remove from temp image name to final image name."""
+    """Move from temp image name to final image name."""
     if not state['success']:
         target_image += '.failed'
 
@@ -324,18 +311,18 @@ def _btrfs_rebalance(mount_point):
             ignore_fail=True)
 
 
-def qemu_debootstrap(state, architecture, distribution, variant, components,
-                     packages, mirror):
+def debootstrap(state, architecture, distribution, variant, components,
+                packages, mirror):
     """Debootstrap into a mounted directory."""
     target = state['mount_point']
     logger.info(
-        'Qemu debootstraping into %s, architecture %s, '
+        'Debootstraping into %s, architecture %s, '
         'distribution %s, variant %s, components %s, build mirror %s', target,
         architecture, distribution, variant, components, mirror)
     try:
         run([
-            'qemu-debootstrap', '--arch=' + architecture,
-            '--variant=' + variant, '--components=' + ','.join(components),
+            'debootstrap', '--arch=' + architecture, '--variant=' + variant,
+            '--components=' + ','.join(components),
             '--include=' + ','.join(packages), distribution, target, mirror
         ])
     except (Exception, KeyboardInterrupt):
@@ -347,8 +334,6 @@ def qemu_debootstrap(state, architecture, distribution, variant, components,
                                ignore_fail=True)
         raise
 
-    schedule_cleanup(state, qemu_remove_binary, state)
-
     # During bootstrap, /etc/machine-id path might be bind mounted.
     schedule_cleanup(state,
                      unmount_filesystem,
@@ -357,13 +342,6 @@ def qemu_debootstrap(state, architecture, distribution, variant, components,
                      ignore_fail=True)
 
 
-def qemu_remove_binary(state):
-    """Remove Qemu binary that may have been installed by qemu-debootstrap."""
-    binaries = path_in_mount(state, 'usr/bin/qemu-*-static')
-    logger.info('Removing qemu binaries %s', binaries)
-    run(['rm', '-f', binaries])
-
-
 @contextlib.contextmanager
 def no_run_daemon_policy(state):
     """Context manager to ensure daemons are not run during installs."""
@@ -382,23 +360,33 @@ exit 101
     os.unlink(path)
 
 
-def install_package(state, package, install_from_backports=False):
+def install_from_backports(state, packages):
+    """Install a package using apt from backports."""
+
+    with no_run_daemon_policy(state):
+        try:
+            logger.info('Installing packages from backports: %s',
+                        " ".join(packages))
+            run_in_chroot(state, [
+                'apt-get', 'install', '-y', *[
+                    f'{package}/{STABLE_CODENAME}-backports'
+                    for package in packages
+                ]
+            ])
+        except cliapp.AppException as ex:
+            logger.info(
+                'Packages not found in backports. Installing from stable.')
+            run_in_chroot(state, ['apt-get', 'install', '-y', *packages])
+
+    run_in_chroot(state, ['apt-get', 'autoremove', '-y'])
+
+
+def install_package(state, package):
     """Install a package using apt."""
     logger.info('Installing package %s', package)
 
     with no_run_daemon_policy(state):
         run_in_chroot(state, ['apt-get', 'install', '-y', package])
-        if install_from_backports:
-            # TODO Install doc-en and doc-es packages too
-            run_in_chroot(state, ['apt-get', 'install', '-y', 'gdebi-core'])
-            run_in_chroot(
-                state,
-                ['apt-get', '-t', 'buster-backports', 'download', package])
-            run_in_chroot(state, ['sh', '-c', f'gdebi -n {package}*.deb'])
-            run_in_chroot(state, [
-                'find', '.', '-maxdepth', '1', '-iname', f'"{package}*.deb"',
-                '-delete'
-            ])
 
 
 def install_custom_package(state, package_path):
@@ -407,10 +395,11 @@ def install_custom_package(state, package_path):
     sub_destination = os.path.join('tmp', os.path.basename(package_path))
     destination_path = path_in_mount(state, sub_destination)
     shutil.copyfile(package_path, destination_path)
-    install_package(state, 'gdebi-core')
     package_path = os.path.join('/tmp', os.path.basename(package_path))
     with no_run_daemon_policy(state):
-        run_in_chroot(state, ['gdebi', '-n', package_path])
+        run_in_chroot(
+            state,
+            ['apt', 'install', '-y', '--allow-downgrades', package_path])
 
 
 def set_hostname(state, hostname):
@@ -439,7 +428,13 @@ def set_hostname(state, hostname):
 
 def get_fstab_options(filesystem_type):
     """Return options to use for a filesystem type."""
-    flags = ['errors=remount-ro'] if not filesystem_type == 'btrfs' else []
+    if filesystem_type == 'btrfs':
+        # Enable btrfs transparent compression. See:
+        # https://fedoraproject.org/wiki/Changes/BtrfsTransparentCompression
+        flags = ['compress=zstd:1']
+    else:
+        flags = ['errors=remount-ro']
+
     return ','.join(flags) or 'defaults'
 
 
@@ -471,12 +466,14 @@ def add_fstab_entry(state, label, filesystem_type, pass_number, append=True):
         file_handle.write(line)
 
 
-def install_grub(state):
+def install_grub(state, target=None, is_efi=False):
     """Install grub boot loader on the loop back device."""
     device = state['loop_device']
     logger.info('Installing grub boot loader on device %s', device)
     run_in_chroot(state, ['update-grub'])
-    run_in_chroot(state, ['grub-install', device])
+    args = [f'--target={target}'] if target else []
+    args += ['--no-nvram'] if is_efi else []
+    run_in_chroot(state, ['grub-install', device] + args)
 
 
 def setup_apt(state, mirror, distribution, components, enable_backports=False):
@@ -494,18 +491,14 @@ deb-src {mirror} {distribution} {components}
     updates_template = '''
 deb {mirror} {distribution}-updates {components}
 deb-src {mirror} {distribution}-updates {components}
-'''
-    old_security_template = '''
-deb http://security.debian.org/debian-security/ {distribution}/updates {components}
-deb-src http://security.debian.org/debian-security/ {distribution}/updates {components}
 '''
     security_template = '''
 deb http://security.debian.org/debian-security/ {distribution}-security {components}
 deb-src http://security.debian.org/debian-security/ {distribution}-security {components}
 '''
-    buster_backports_template = '''
-deb http://deb.debian.org/debian buster-backports main
-deb-src http://deb.debian.org/debian buster-backports main
+    backports_template = f'''
+deb http://deb.debian.org/debian {STABLE_CODENAME}-backports main
+deb-src http://deb.debian.org/debian {STABLE_CODENAME}-backports main
 '''
     file_path = path_in_mount(state, 'etc/apt/sources.list')
     with open(file_path, 'w') as file_handle:
@@ -513,11 +506,9 @@ deb-src http://deb.debian.org/debian buster-backports main
         if distribution not in ('sid', 'unstable'):
             file_handle.write(updates_template.format(**values))
             if enable_backports:
-                file_handle.write(buster_backports_template)
-            if distribution in ('bullseye', 'testing'):
-                file_handle.write(security_template.format(**values))
-            else:  # stable/buster
-                file_handle.write(old_security_template.format(**values))
+                file_handle.write(backports_template)
+
+            file_handle.write(security_template.format(**values))
 
     run_in_chroot(state, ['apt-get', 'update'])
     run_in_chroot(state, ['apt-get', 'clean'])
@@ -543,7 +534,7 @@ def setup_flash_kernel(state, machine_name, kernel_options,
 
     run_in_chroot(state, ['apt-get', 'install', '-y', 'flash-kernel'])
 
-    # flash-kernel creates links in /boot and does not work with the filesystem
+    # flash-kernel creates links in /boot and does not work when the filesystem
     # is vfat.
     if boot_filesystem_type != 'vfat':
         run_in_chroot(state, ['flash-kernel'])
