@@ -593,12 +593,13 @@ deb-src http://security.debian.org/debian-security/ stable-security main
         ])
 
         unstable_content = '''
-deb http://ftp.us.debian.org/debian unstable main contrib non-free
-deb-src http://ftp.us.debian.org/debian unstable main contrib non-free
+deb http://ftp.us.debian.org/debian unstable main contrib non-free-firmware
+deb-src http://ftp.us.debian.org/debian unstable main contrib non-free-firmware
 '''
         with self.assert_file_change(sources_path, None, unstable_content):
             library.setup_apt(self.state, 'http://ftp.us.debian.org/debian',
-                              'unstable', ['main', 'contrib', 'non-free'])
+                              'unstable',
+                              ['main', 'contrib', 'non-free-firmware'])
 
     @patch('freedommaker.library.run_in_chroot')
     def test_setup_flash_kernel(self, run):
