@@ -1,19 +1,4 @@
-#
-# This file is part of Freedom Maker.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: GPL-3.0-or-later
 """
 Tests for miscellaneous utility methods.
 """
@@ -27,13 +12,16 @@ class TestUtils(unittest.TestCase):
     """Test for miscellaneous utility methods."""
     def test_add_disk_offsets(self):
         """Test disk offset addition."""
-        self.assertEqual(utils.add_disk_offsets('1mib', '2mib'), '3mib')
-        self.assertRaises(NotImplementedError, utils.add_disk_offsets, '1gib',
-                          '1mib')
+        self.assertEqual(utils.add_disk_offsets('1MiB', '2MiB'), '3MiB')
+        # mib is not allowed as unit. Only MiB.
         self.assertRaises(NotImplementedError, utils.add_disk_offsets, '1mib',
-                          '1gib')
-        self.assertRaises(ValueError, utils.add_disk_offsets, 'xmib', '1mib')
-        self.assertRaises(ValueError, utils.add_disk_offsets, 'xmib', 'xmib')
+                          '1mib')
+        self.assertRaises(NotImplementedError, utils.add_disk_offsets, '1GiB',
+                          '1MiB')
+        self.assertRaises(NotImplementedError, utils.add_disk_offsets, '1MiB',
+                          '1GiB')
+        self.assertRaises(ValueError, utils.add_disk_offsets, 'xMiB', '1MiB')
+        self.assertRaises(ValueError, utils.add_disk_offsets, 'xMiB', 'xMiB')
 
     def test_parse_disk_size(self):
         """Test parsing disk sizes."""
